==> simple_json_logger-0.0.2.tar.gz: simple_json_logger-0.0.2/simple_json_logger/logger.py <==
import sys
import json
import logging

from .formatter import JsonFormatter


class StdoutFilter(logging.Filter):
    def filter(self, rec):
        return rec.levelno in (logging.DEBUG, logging.INFO)


class JsonLogger(logging.Logger):
    def __init__(self, name='json_logger',
                 level=logging.DEBUG,
                 serializer=json.dumps,
                 stream=None):
        """
        :type name: str
        :type level: int
        :type serializer: callable
        """
        super().__init__(name, level)
        self.serializer = serializer

        if stream:
            handler = self._make_handler(level=level, stream=stream)
            self.addHandler(handler)
        else:
            self.addHandler(self._stdout_handler)
            self.addHandler(self._stderr_handler)

    @property
    def _stdout_handler(self):
        """
        :rtype: logging.StreamHandler
        """
        handler = self._make_handler(level=logging.DEBUG, stream=sys.stdout)
        handler.addFilter(StdoutFilter())
        return handler

    @property
    def _stderr_handler(self):
        """
        :rtype: logging.StreamHandler
        """
        return self._make_handler(level=logging.WARNING, stream=sys.stderr)

    def _make_handler(self, level, stream) -> 'logging.StreamHandler':
        """
        :rtype: logging.StreamHandler
        """
        handler = logging.StreamHandler(stream)
        handler.setLevel(level)
        handler.setFormatter(JsonFormatter(self.serializer))

        return handler

==> simple_json_logger-0.1.0.tar.gz: simple_json_logger-0.1.0/simple_json_logger/logger.py <==
import sys
import json
import logging

from .formatter import JsonFormatter


class StdoutFilter(logging.Filter):
    def filter(self, rec):
        return rec.levelno in (logging.DEBUG, logging.INFO)


class JsonLogger(logging.Logger):
    def __init__(self, name='json_logger',
                 level=logging.DEBUG,
                 serializer=json.dumps,
                 stream=None):
        """
        :type name: str
        :type level: int
        :type serializer: callable
        """
        super(JsonLogger, self).__init__(name, level)
        self.serializer = serializer

        if stream:
            handler = self._make_handler(level=level, stream=stream)
            self.addHandler(handler)
        else:
            self.addHandler(self._stdout_handler)
            self.addHandler(self._stderr_handler)

    @property
    def _stdout_handler(self):
        """
        :rtype: logging.StreamHandler
        """
        handler = self._make_handler(level=logging.DEBUG, stream=sys.stdout)
        handler.addFilter(StdoutFilter())
        return handler

    @property
    def _stderr_handler(self):
        """
        :rtype: logging.StreamHandler
        """
        return self._make_handler(level=logging.WARNING, stream=sys.stderr)

    def _make_handler(self, level, stream):
        """
        :rtype: logging.StreamHandler
        """
        handler = logging.StreamHandler(stream)
        handler.setLevel(level)
        handler.setFormatter(JsonFormatter(self.serializer))

        return handler
